@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: image_ui.c,v 1.5.2.15 2004/11/09 22:42:28 fuyu Exp $
+ * $Id: image_ui.c,v 1.5.2.16 2005/02/18 20:07:30 fuyu Exp $
  */
 
 #include "config.h"
@@ -117,7 +117,13 @@ image_info_free(ImageInfo *info)
   /* gdk_threads_enter()ĶƤӽФ */
   g_free(info->url);
   if (info->loader != NULL)
-    g_object_unref(info->loader);
+    {
+#if 0
+      fprintf(stderr, "image_info_free: loader(%p)->ref_count=%d\n",
+	      info->loader, ((GObject *)info->loader)->ref_count);
+#endif
+      g_object_unref(info->loader);
+    }
   if (info->animation != NULL)
     g_object_unref(info->animation);
   if (info->pixbuf != NULL)
@@ -487,6 +493,10 @@ set_pixbuf(ImageInfo *image_info)
     }
 
   image_info->loader = NULL;
+#if 0
+  fprintf(stderr, "set_pixbuf: loader(%p)->ref_count=%d\n",
+	  loader, ((GObject *)loader)->ref_count);
+#endif
   g_object_unref(loader);
 
   if (image_info->widget_list == NULL
@@ -631,6 +641,10 @@ download_image(WorkerThread *employee, gpointer args)
 
   OCHU_OBJECT_UNREF(buffer);
 
+#if 0
+  fprintf(stderr, "download_image: loader(%p)->ref_count=%d\n",
+	  loader, ((GObject *)loader)->ref_count);
+#endif
   g_object_unref(loader);
 }
 
@@ -776,6 +790,9 @@ ochusha_download_image(OchushaApplication *application, const char *url,
     return NULL;
 
   loader = gdk_pixbuf_loader_new();
+#if 0
+  fprintf(stderr, "ochusha_download_image(): loader=%p\n", loader);
+#endif
   image = gtk_image_new_from_stock(OCHUSHA_STOCK_MISSING_IMAGE,
 				   GTK_ICON_SIZE_DIALOG);
   image_info = image_info_new(url, loader, image);
