@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_thread_2ch.c,v 1.71.2.5 2004/11/25 08:59:45 fuyu Exp $
+ * $Id: ochusha_thread_2ch.c,v 1.71.2.8 2005/06/10 14:28:03 fuyu Exp $
  */
 
 #include "config.h"
@@ -52,6 +52,17 @@
 #include <zlib.h>
 
 
+#if HAVE_ONIG_ONIGURUMA_H
+# include <onig/oniguruma.h>
+#else
+# include <oniguruma.h>
+#endif
+
+#if (ONIGURUMA_VERSION_MAJOR < 2) && (ONIGURUMA_VERSION_MINOR < 2)
+#error "Please use included oniguruma, we no longer support oniguruma prior to 2.2"
+#endif
+
+
 #define DEBUG_DAT	0
 #define DEBUG_DAT_MOST	0
 
@@ -153,6 +164,11 @@ static OchushaBBSThreadClass *parent_class = NULL;
 static GQuark idle_checker_id;
 
 
+static const char * const be_link_pattern_string
+    = "<?BE:([0-9]+)[:-]([0-9]+|#*)>?";
+static const char *be_link_pattern_end = NULL;
+
+
 static void
 ochusha_thread_2ch_class_init(OchushaThread2chClass *klass)
 {
@@ -193,6 +209,10 @@ ochusha_thread_2ch_class_init(OchushaThread2chClass *klass)
 
   idle_checker_id
     = g_quark_from_static_string("OchushaThread2ch::IdleChecker");
+
+  if (be_link_pattern_end == NULL)
+    be_link_pattern_end
+      = be_link_pattern_string + strlen(be_link_pattern_string);
 }
 
 
@@ -509,8 +529,18 @@ ochusha_thread_2ch_get_base_url(OchushaBBSThread *thread)
   g_return_val_if_fail(OCHUSHA_IS_THREAD_2CH(thread), NULL);
 
   thread_2ch = OCHUSHA_THREAD_2CH(thread);
+#if 0
   if (thread_2ch->base_url != NULL && thread_2ch->kako_html == NULL)
     return thread_2ch->base_url;
+#else
+  if (thread_2ch->base_url != NULL)
+    {
+      /* URLΥå᤿call siteľƤޤΤ
+       * ݤʤΤǡad-hoc˽*/
+      G_FREE(thread_2ch->base_url);
+      thread_2ch->base_url = NULL;
+    }
+#endif
 
   base_path = ochusha_thread_2ch_get_base_path(thread_2ch);
 
@@ -1266,6 +1296,10 @@ ochusha_thread_2ch_parse_responses(OchushaBBSThread *thread,
   gboolean result = TRUE;
   OchushaNetworkBrokerBufferStatus *status;
   OchushaNetworkBrokerBufferStatus fake_status;
+#if 1
+  regex_t *be_pattern = NULL;
+  OnigRegion *match_region = NULL;
+#endif
 
   g_return_val_if_fail(OCHUSHA_IS_THREAD_2CH(thread)
 		       && OCHUSHA_IS_ASYNC_BUFFER(buffer), FALSE);
@@ -1290,6 +1324,18 @@ ochusha_thread_2ch_parse_responses(OchushaBBSThread *thread,
       return FALSE;
     }
 
+#if 1
+  if (onig_new(&be_pattern,
+	       (char *)be_link_pattern_string, (char *)be_link_pattern_end,
+	       ONIG_OPTION_NONE, ONIG_ENCODING_SJIS,
+	       ONIG_SYNTAX_RUBY, NULL) != ONIG_NORMAL)
+    {
+      fprintf(stderr, "invalid regular expression in be_link_pattern.\n");
+      be_pattern = NULL;
+    }
+  match_region = onig_region_new();
+#endif
+
   thread_2ch = OCHUSHA_THREAD_2CH(thread);
 
   responses = thread_2ch->responses;
@@ -1412,8 +1458,61 @@ ochusha_thread_2ch_parse_responses(OchushaBBSThread *thread,
 		if (title_pos != NULL)
 		  {
 		    if (each_response_cb != NULL)
-		      result = (*each_response_cb)(thread, i, &response,
-						   callback_data);
+		      {
+			char *date_id = (char *)response.date_id;
+			char *date_id_end = date_id + strlen(response.date_id);
+
+			if (onig_search(be_pattern,
+					date_id, date_id_end,
+					date_id, date_id_end,
+					match_region, 0) >= 0)
+			  {
+			    /*
+			     * BEdate_id񤭴롣
+			     */
+			    char *tmp_date_id;
+			    char lv_buf[128];
+			    size_t prof_len
+			      = match_region->end[1] - match_region->beg[1];
+			    char *profile
+			      = g_strndup(date_id + match_region->beg[1],
+					  prof_len);
+			    size_t lv_len
+			      = match_region->end[2] - match_region->beg[2];
+			    if (lv_len == 0
+				|| date_id[match_region->beg[2]] == '#')
+			      {
+				int i = 0;
+				char *lv_pos = date_id + match_region->beg[2];
+				while (*lv_pos++ == '#')
+				  i++;
+				snprintf(lv_buf, 128, "%d", i);
+			      }
+			    else
+			      {
+				date_id[match_region->end[2]] = '\0';
+				snprintf(lv_buf, 128, "%s",
+					 date_id + match_region->beg[2]);
+			      }
+			    date_id[match_region->beg[0]] = '\0';
+			    tmp_date_id
+			      = g_strconcat(date_id,
+					    "<a href=\"http://be.2ch.net/test/p.php?i=",
+					    profile, "&u=d:",
+					    ochusha_bbs_thread_get_url(thread),
+					    "\">Lv.", lv_buf, "</a>",
+					    date_id + match_region->end[0],
+					    NULL);
+#if 0
+			    fprintf(stderr, "BE:%s\n", tmp_date_id);
+#endif
+			    g_free(date_id);
+			    g_free(profile);
+			    response.date_id = tmp_date_id;
+			  }
+			result = (*each_response_cb)(thread, i, &response,
+						     callback_data);
+		      }
 #if 0
 		    /*
 		     * Ƴ()ߤʤΤǡᡣ
@@ -1522,24 +1621,27 @@ ochusha_thread_2ch_parse_responses(OchushaBBSThread *thread,
 	    /*
 	     * GUIΥ쥹ݥ󥹤βܻؤ¸
 	     */
-	    OCHU_OBJECT_REF(buffer);
-	    g_object_set_qdata(G_OBJECT(buffer), idle_checker_id, buffer);
-	    g_idle_add_full(G_PRIORITY_HIGH_IDLE + 15,
-			    advance_parsing, buffer, NULL);
-	    if (before_wait_cb != NULL)
-	      (*before_wait_cb)(callback_data);
-	    do
+	    if (!no_wait)
 	      {
-		if (!ochusha_async_buffer_wait(buffer))
+		OCHU_OBJECT_REF(buffer);
+		g_object_set_qdata(G_OBJECT(buffer), idle_checker_id, buffer);
+		g_idle_add_full(G_PRIORITY_HIGH_IDLE + 15,
+				advance_parsing, buffer, NULL);
+		if (before_wait_cb != NULL)
+		  (*before_wait_cb)(callback_data);
+		do
 		  {
-		    if (after_wait_cb != NULL)
-		      (*after_wait_cb)(callback_data);
-		    goto terminated;
-		  }
-	      } while (g_object_get_qdata(G_OBJECT(buffer), idle_checker_id)
-		       != NULL);
-	    if (after_wait_cb != NULL)
-	      (*after_wait_cb)(callback_data);
+		    if (!ochusha_async_buffer_wait(buffer))
+		      {
+			if (after_wait_cb != NULL)
+			  (*after_wait_cb)(callback_data);
+			goto terminated;
+		      }
+		  } while (g_object_get_qdata(G_OBJECT(buffer),
+					      idle_checker_id) != NULL);
+		if (after_wait_cb != NULL)
+		  (*after_wait_cb)(callback_data);
+	      }
 	    interval = ANALYSIS_INTERVAL;
 	  }
 
@@ -1592,6 +1694,11 @@ ochusha_thread_2ch_parse_responses(OchushaBBSThread *thread,
   if (thread->board->bbs_type == OCHUSHA_BBS_TYPE_2CH_HEADLINE)
     thread->number_of_responses_read = 0;
 
+  if (be_pattern != NULL)
+    onig_free(be_pattern);
+  if (match_region != NULL)
+    onig_region_free(match_region, 1);
+
   return TRUE;
 }
 
