@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_thread_jbbs.c,v 1.38.2.2 2004/11/25 08:59:45 fuyu Exp $
+ * $Id: ochusha_thread_jbbs.c,v 1.38.2.6 2005/06/10 14:27:28 fuyu Exp $
  */
 
 #include "config.h"
@@ -54,7 +54,7 @@
 # include <oniguruma.h>
 #endif
 
-#if (ONIGURUMA_VERSION_MAJOR < 2) || (ONIGURUMA_VERSION_MINOR < 2)
+#if (ONIGURUMA_VERSION_MAJOR < 2) && (ONIGURUMA_VERSION_MINOR < 2)
 #error "Please use included oniguruma, we no longer support oniguruma prior to 2.2"
 #endif
 
@@ -293,10 +293,7 @@ extract_jbbs_response(char *start_pos, char *eol_pos,
    *
    * ǶDATɤ߹褦ˤʤäJBBSФʷǼĤξ硢
    * ֹ<>ᥤ<><>쥹<>[åɥȥ]<>[ۥorID]
-   * ȤˤʤäƤ롣
-   *
-   * ᤤˤη򥵥ݡȤޤBBSʤɤǹƤDATե
-   * ηѹͽ2chΤޤޤˤʤäƤ롣
+   * ȤˤʤäƤ롣̯ѤäϤʤΤץå
    */
   char *clone_buffer = NULL;
   char *cur_pos = start_pos;
@@ -855,11 +852,12 @@ ochusha_thread_jbbs_get_url_for_response(OchushaBBSThread *thread, int from,
       {
 	if (from >= to)
 	  to = from;
-	snprintf(url, PATH_MAX, "http://%s%sbbs/read.cgi?BBS=%s&KEY=%s&START=%d&END=%d&NOFIRST=TRUE",
-		 ochusha_bulletin_board_get_server(thread->board),
-		 ochusha_bulletin_board_get_base_path(thread->board),
-		 ochusha_bulletin_board_get_id(thread->board),
-		 thread->id, from, to);
+	if (to == from)
+	  snprintf(url, PATH_MAX, "%s%d",
+		   ochusha_bbs_thread_get_url(thread), from);
+	else
+	  snprintf(url, PATH_MAX, "%s%d-%d",
+		   ochusha_bbs_thread_get_url(thread), from, to);
 	break;
       }
 
@@ -896,13 +894,16 @@ ochusha_thread_jbbs_get_url_to_post(OchushaBBSThread *thread)
   switch (thread->board->bbs_type)
     {
     case OCHUSHA_BBS_TYPE_MACHIBBS:
-    case OCHUSHA_BBS_TYPE_JBBS_SHITARABA:
       snprintf(url, PATH_MAX, "%s?BBS=%s&KEY=%s&LAST=10",
 	       ochusha_board_2ch_get_read_cgi_url(OCHUSHA_BOARD_2CH(thread->board)),
 	       ochusha_bulletin_board_get_id(thread->board),
 	       thread->id);
       break;
 
+    case OCHUSHA_BBS_TYPE_JBBS_SHITARABA:
+      snprintf(url, PATH_MAX, "%sl10", ochusha_bbs_thread_get_url(thread));
+      break;
+
     case OCHUSHA_BBS_TYPE_MITINOKU:
       snprintf(url, PATH_MAX, "%s?bbs=%s&key=%s&ls=10",
 	       ochusha_board_2ch_get_read_cgi_url(OCHUSHA_BOARD_2CH(thread->board)),
@@ -1014,56 +1015,45 @@ typedef struct _HTML2DATConverterJobArgs
 } HTML2DATConverterJobArgs;
 
 
-static const char *title_pattern_string = NULL;
+static const char * const title_pattern_string = "<title>(.*)</title>";
 static const char *title_pattern_end = NULL;
-static const char *jbbs_shitaraba_response_pattern_string = NULL;
+
+#define NAME_EUCJP	"\314\276\301\260\241\247"	   /* "̾" */
+#define DATE_EUCJP	"\305\352\271\306\306\374\241\247" /* "" */
+static const char * const jbbs_shitaraba_response_pattern_string
+    = "(?i:<dt><a href[^>]*>)([1-9][0-9]*)(?i:</a>) " NAME_EUCJP
+      "[^<]*(<(?i:font)[^>]*|<(?i:a)[^>]*)>(.*)" DATE_EUCJP
+      " (.*)(?i:<br><dd>)(.*)(?i:<br><br>)$";
 static const char *jbbs_shitaraba_response_pattern_end = NULL;
-static const char *machibbs_response_pattern_string = NULL;
-static const char *machibbs_response_pattern_end = NULL;
-static const char *mitinoku_response_pattern_string = NULL;
+
+static const char * const mitinoku_response_pattern_string
+    = "(?i:<dt>)([1-9][0-9]*) " NAME_EUCJP
+      "[^<]*(<(?i:font)[^>]*|<(?i:a)[^>]*)>(.*)" DATE_EUCJP
+      "(.*)(?i:<dd>)(.*)(?i:<br><br>)$";
 static const char *mitinoku_response_pattern_end = NULL;
 
+#define NAME_SJIS	"\226\274\221\117\201\106"	   /* "̾" */
+#define DATE_SJIS	"\223\212\215\145\223\372\201\106" /* "" */
+static const char * const machibbs_response_pattern_string
+    = "(?i:<dt>)([1-9][0-9]*) " NAME_SJIS
+      "[^<]*(<(?i:font)[^>]*|<(?i:a)[^>]*)>(.*)" DATE_SJIS
+      " (.*)(?i:<br><dd>)(.*)(?i:<br><br>)$";
+static const char *machibbs_response_pattern_end = NULL;
+
 
 static void
 initialize_default_regexp_patterns(void)
 {
-  title_pattern_string = "<title>(.*)</title>";
   title_pattern_end = title_pattern_string + strlen(title_pattern_string);
 
-#define NAME_EUCJP	"\314\276\301\260\241\247"	   /* "̾" */
-#define DATE_EUCJP	"\305\352\271\306\306\374\241\247" /* "" */
-
-  jbbs_shitaraba_response_pattern_string
-    = "(?i:<dt>)([1-9][0-9]*) " NAME_EUCJP
-      "[^<]*(<(?i:font)[^>]*|<(?i:a)[^>]*)>(.*)" DATE_EUCJP
-      " (.*)(?i:<br><dd>)(.*)(?i:<br><br>)$";
   jbbs_shitaraba_response_pattern_end
     = (jbbs_shitaraba_response_pattern_string
        + strlen(jbbs_shitaraba_response_pattern_string));
 
-  mitinoku_response_pattern_string
-    = "(?i:<dt>)([1-9][0-9]*) " NAME_EUCJP
-      "[^<]*(<(?i:font)[^>]*|<(?i:a)[^>]*)>(.*)" DATE_EUCJP
-      "(.*)(?i:<dd>)(.*)(?i:<br><br>)$";
   mitinoku_response_pattern_end
     = (mitinoku_response_pattern_string
        + strlen(mitinoku_response_pattern_string));
 
-
-#define NAME_SJIS	"\226\274\221\117\201\106"	   /* "̾" */
-#define DATE_SJIS	"\223\212\215\145\223\372\201\106" /* "" */
-
-#if 1	/* ޤ££ӤĴҰƥƥȤǤ͡ġ */
-  machibbs_response_pattern_string
-    = "(?i:<dt>)([1-9][0-9]*) " NAME_SJIS
-      "[^<]*(<(?i:font)[^>]*|<(?i:a)[^>]*)>(.*)" DATE_SJIS
-      " (.*)(?i:<br><dd>)(.*)(?i:<br><br>)$";
-#else
-  machibbs_response_pattern_string
-    = "<[dD][tT]>([1-9][0-9]*) " NAME_SJIS
-      "[^<]*(<[fF][oO][nN][tT][^>]*|<[aA][^>]*)>(.*)" DATE_SJIS
-      " (.*)<[bB][rR]><[dD][dD]>(.*)<[bB][rR]><[bB][rR]>$";
-#endif
   machibbs_response_pattern_end
     = (machibbs_response_pattern_string
        + strlen(machibbs_response_pattern_string));
@@ -1086,8 +1076,9 @@ convert_html_to_dat(WorkerThread *employee, HTML2DATConverterJobArgs *args)
   regex_t *title_pattern = NULL;
   regex_t *response_pattern = NULL;
   OnigRegion *match_region = NULL;
+  char *previous_line = NULL;
 
-  if (title_pattern_string == NULL)
+  if (title_pattern_end == NULL)
     initialize_default_regexp_patterns();
 
   switch (thread->board->bbs_type)
@@ -1214,7 +1205,6 @@ convert_html_to_dat(WorkerThread *employee, HTML2DATConverterJobArgs *args)
       char *html_buffer_pos = html_buffer_top + html_offset;
       int rest_of_data = html_buffer->length - html_offset;
       char *eol_pos = NULL;
-      char *previous_line = NULL;
 
 #if DEBUG_HTML_TO_DAT_CONVERTER_MOST
       fprintf(stderr,
@@ -1653,6 +1643,9 @@ ochusha_thread_jbbs_fake_responses_source(OchushaThread2ch *thread_2ch,
 
   if (mode != OCHUSHA_NETWORK_BROKER_CACHE_IGNORE)
     {
+      if (buffer != NULL)
+	incoming_offset = buffer->length;
+
       if (buffer == NULL || !ochusha_async_buffer_reset(buffer))
 	{
 	  int fd = ochusha_config_cache_open_file(broker->config, fake_dat_url,
@@ -1678,11 +1671,13 @@ ochusha_thread_jbbs_fake_responses_source(OchushaThread2ch *thread_2ch,
 		}
 	      close(fd);
 	    }
+	  else
+	    incoming_offset = 0;
 	}
       else
 	{
 	  dat_buffer = buffer;
-	  incoming_offset = buffer->length;
+	  ochusha_async_buffer_update_length(dat_buffer, incoming_offset);
 	}
 
       /* ¸Υ쥹 */
@@ -1705,7 +1700,6 @@ ochusha_thread_jbbs_fake_responses_source(OchushaThread2ch *thread_2ch,
     {
     case OCHUSHA_BBS_TYPE_JBBS:
     case OCHUSHA_BBS_TYPE_MACHIBBS:
-    case OCHUSHA_BBS_TYPE_JBBS_SHITARABA:
       if (snprintf(cgi_url, PATH_MAX, "%s?BBS=%s&KEY=%s&START=%d%s",
 		   ochusha_board_2ch_get_read_cgi_url(board_2ch),
 		   thread->board->id, thread->id,
@@ -1715,6 +1709,13 @@ ochusha_thread_jbbs_fake_responses_source(OchushaThread2ch *thread_2ch,
 	cgi_url[0] = '\0';
       break;
 
+    case OCHUSHA_BBS_TYPE_JBBS_SHITARABA:
+      if (snprintf(cgi_url, PATH_MAX, "%s%d-",
+		   ochusha_bbs_thread_get_url(thread),
+		   number_of_cached_responses + 1) >= PATH_MAX)
+	cgi_url[0] = '\0';
+      break;
+
     case OCHUSHA_BBS_TYPE_MITINOKU:
       if (thread->number_of_responses_on_server <= number_of_cached_responses)
 	return dat_buffer;
